/* 
This program (formats_for_boat_file.sas) creates the formats
catalog for boat_file.sas7bdat.

Instructions for Windows users:

1. Create a folder for your files, e.g. c:\sasfiles
2. Place boat_file.sas7bdat and formats_for_boat_file.sas
   in the folder
3. Edit the libname statement in formats_for_boat_file.sas so that
   it refers to the folder, e.g.: libname library 'c:\sasfiles'
4. Open and run formats_for_boat_file.sas.  This will create
   the formats catalog, "formats.sas7bcat" in that folder.
5. You may now use boat_file.sas7bdat any way you
   like, for example the following program will create a frequency listing:

   libname library 'c:\sasfiles';
   proc freq data=library.boat_file; 
      tables _all_;
   run;

   Note that by using the name "library" for your libname when inputting the 
   data, SAS will automatically look in that same location for the formats
   catalog.  Otherwise, you would need to use a "fmtsearch" option to tell
   SAS where to look for the formats catalog.
*/

libname library '';

proc format library=library;

   value V00015F 
      1 = "01-A POWERBOAT,"
      2 = "02-A SAILBOAT"
      3 = "03-A PERSONAL WATERCRAFT SUCH AS A JET SKI"
      4 = "04-CANOE"
      5 = "05-KAYAK"
      6 = "06-SOMETHING ELSE"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED"
   ;
   value V00040F 
      1 = "01-YES"
      2 = "02-NO"
      88 = "88-INVALID RESPONSE"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED/MISSING"
   ;
   value DKRF2F 
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED"
   ;
   value DKRF3F 
      997 = "997-DON'T KNOW"
      999 = "999-REFUSED"
   ;
   value V00070F 
      1 = "01-YES"
      2 = "02-NO"
      88 = "88-INVALID RESPONSE"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED/MISSING"
   ;
   value V00204F 
      1 = "01-REGISTERED/YES"
      2 = "02-UNREGISTERED/NO"
      88 = "88-INVALID RESPONSE"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED/MISSING"
   ;
   value V00195F 
      1 = "01-ALABAMA"
      2 = "02-ALASKA"
      4 = "04-ARIZONA"
      5 = "05-ARKANSAS"
      6 = "06-CALIFORNIA"
      8 = "08-COLORADO"
      9 = "09-CONNECTICUT"
      10 = "10-DELAWARE"
      11 = "11-DC"
      12 = "12-FLORIDA"
      13 = "13-GEORGIA"
      15 = "15-HAWAII"
      16 = "16-IDAHO"
      17 = "17-ILLINOIS"
      18 = "18-INDIANA"
      19 = "19-IOWA"
      20 = "20-KANSAS"
      21 = "21-KENTUCKY"
      22 = "22-LOUISIANA"
      23 = "23-MAINE"
      24 = "24-MARYLAND"
      25 = "25-MASSACHUSETTS"
      26 = "26-MICHIGAN"
      27 = "27-MINNESOTA"
      28 = "28-MISSISSIPPI"
      29 = "29-MISSOURI"
      30 = "30-MONTANA"
      31 = "31-NEBRASKA"
      32 = "32-NEVADA"
      33 = "33-NEW HAMPSHIRE"
      34 = "34-NEW JERSEY"
      35 = "35-NEW MEXICO"
      36 = "36-NEW YORK"
      37 = "37-NORTH CAROLINA"
      38 = "38-NORTH DAKOTA"
      39 = "39-OHIO"
      40 = "40-OKLAHOMA"
      41 = "41-OREGON"
      42 = "42-PENNSYLVANIA"
      44 = "44-RHODE ISLAND"
      45 = "45-SOUTH CAROLINA"
      46 = "46-SOUTH DAKOTA"
      47 = "47-TENNESSEE"
      48 = "48-TEXAS"
      49 = "49-UTAH"
      50 = "50-VERMONT"
      51 = "51-VIRGINIA"
      53 = "53-WASHINGTON"
      54 = "54-WEST VIRGINA"
      55 = "55-WISCONSIN"
      56 = "56-WYOMING"
      72 = "72-PUERTO RICO"
      88 = "88-INVALID RESPONSE"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED/MISSING"
   ;
   value V00299F 
      1 = "01-A ROWBOAT"
      2 = "02-AN INFLATABLE"
      3 = "03-NEITHER"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED"
   ;
   value V00308F 
      1 = "01-A CABIN MOTORBOAT"
      2 = "02-A JET BOAT"
      3 = "03-AN OPEN MOTORBOAT"
      4 = "04-A PONTOON BOAT"
      5 = "05-A HOUSEBOAT"
      6 = "06-AN AIRBOAT"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED"
   ;
   value V00317F 
      1 = "01-AN AUXILIARY MOTOR SAILBOAT"
      2 = "02-A SAIL-ONLY SAILBOAT"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED"
   ;
   value V00361F 
      1 = "01-YES"
      2 = "02-NO"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED"
   ;
   value V00362F 
      1 = "01-YES"
      2 = "02-NO"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED"
   ;
   value $MSUBOATSPECF 
      "01" = "01-CABIN MOTORBOAT"
      "02" = "02-JET BOAT"
      "03" = "03-OPEN MOTORBOAT"
      "04" = "04-PONTOON BOAT"
      "05" = "05-HOUSEBOAT"
      "06" = "06-AIR BOAT"
      "07" = "07-SOME POWER BOAT TYPE"
      "08" = "08-AUXILLARY MOTOR SAIL"
      "09" = "09-SAIL-ONLY SAILBOAT"
      "10" = "10-SOME SAILBOAT TYPE"
      "11" = "11-PWC, JET SKI"
      "12" = "12-CANOE"
      "13" = "13-KAYAK"
      "14" = "14-ROWBOAT"
      "15" = "15-INFLATABLE"
      "16" = "16-SOME OTHER BOAT TYPE"
      "88" = "88-INVALID RESPONSE"
      "97" = "97-DO NOT KNOW"
      "99" = "99-MISSING"
   ;
   value $BOATTYPF 
      "1A" = "1A-Power Boat <16ft"
      "1B" = "1B-Power Boat 16 - 20ft"
      "1C" = "1C-Power Boat 21 - 28ft"
      "1D" = "1D-Power Boat >28"
      "2A" = "2A-Sail < 26"
      "2B" = "2B-Sail >= 26"
      "3" = "3-PWC"
      "4" = "4-Canoe"
      "45" = "45-Self-propelled"
      "5" = "5-Kayak"
      "6A" = "6A-Pontoon"
      "6B" = "6B-Other"
      "6C" = "6C-Rowboat/inflatable"
   ;
   value $MSUVERIFYLENGTHF 
      "-" = "- -LENGTH WAS NOT PROVIDED"
      "L" = "Y-LENGTH PROVIDED WAS TOO LONG"
      "S" = "Y-LENGTH PROVIDED WAS TOO SHORT"
      "Y" = "Y-LENGTH PROVIDED VERIFIED PROPER"
   ;
	VALUE btyp7f  
		.='All Types' 
		1='Power boats'
		2='Sail boats'  
		3='PWCs'
		4='Canoes' 
		5='Kayaks'
		6='Pontoons'  
		7='Row/Inf/Oth boats'
	   45='Canoes & Kayaks (PR only)'  /* for Puerto Rico only */
	  267='Other Boats - PR only (includes sail, pontoon, others ..)'/* for Puerto Rico only */
	;
	VALUE lngf   
		1='<16 FT'   
		2='16-25.9 FT'
		3='26-39.9 FT'
		4='40-64.9 FT'
		5='65+ FT'  
		6='Unknown'
	;
	VALUE regionf
		.='United States.....'
		1='Northeast.........'
		2='Midwest...........'
		3='South.............'   
		4='West..............'
		9='72: Puerto Rico...'
	;
   value subtype_fmt 
       1 = "(1) Cabin Motorboat"
       2 = "(2) Jet Boat"
       3 = "(3) Open Motorboat"
       4 = "(4) Pontoon Boat"
       5 = "(5) Houseboat"
       6 = "(6) Air Boat"
       7 = "(7) Some Power Boat Type"
       8 = "(8) Auxilliary Motor Sail"
       9 = "(9) Sail Only Sail Boat"
      10 = "(10) Some Sail Boat Type"
      11 = "(11) PWC, Jet Ski"
      12 = "(12) Canoe"
      13 = "(13) Kayak"
      14 = "(14) Rowboat"
      15 = "(15) Inflatable"
      16 = "(16) Some Other Boat Type"
      88 = "(88) Invalid Response"
      97 = "(97) Do Not Know"
      99 = "(99) Missing"
	  45 = "(45) Canoes & Kayaks (PR only)"  /* for Puerto Rico only */
	 267 = "(267) Other Boats - PR only (includes sail, pontoon, others ..)"/* for Puerto Rico only */
   ;
run;
